@@ -9,7 +9,7 @@ import pathlib
 from pathlib import Path
 from pkglogger import pkglogger
 
-def find_file(sequence_no,target_path='',file_name='',extension=''):
+def find_file(sequence_no,source_path='',target_path='',file_name='',extension=''):
     '''
     Note : This function will work for exclusively packages \n
            where you need to shift from one location        \n
@@ -17,7 +17,9 @@ def find_file(sequence_no,target_path='',file_name='',extension=''):
            Function is not case-sensistive                  \n
            
     sequence_no : Pass the number of steps you want to go back                                           \n
-                  Start with : 0 which is just earlier directory                                         \n
+                  Start with : 0 which is just the home directory from where you are running the file    \n
+    source_path : Pass the source path where you want to perform the action                              \n
+                  Optional : If you have nothing to pass it will get default current working directory ) \n
     target_path : Pass the absolute path / list of folders as a sequence you want to traverse as a list  \n 
                   Example : For multiple folders --> ['folder1','folder2','folder3',....]                \n
                             For Single absolute path --> folder1/folder2/folder3/.....                   \n
@@ -29,15 +31,19 @@ def find_file(sequence_no,target_path='',file_name='',extension=''):
                   ( Optional : If you only need to go to path )                                          \n
                   Example : txt, py, png etc...
     '''
-    executable_dir = os.path.dirname(__file__)
+    if len(source_path) == 0: 
+        executable_dir = getcwd() # os.path.abspath(__file__)
+    else:
+        executable_dir = source_path
+    print("Working Path",executable_dir)
     if type(target_path) != list:
-        destination = os.path.join(Path(executable_dir).parents[sequence_no],target_path)
+        destination = pathlib.Path(os.path.join(Path(executable_dir).parents[sequence_no],target_path))
     else:
         try:
             for i in range(0,len(target_path)):
-                destination = os.path.join(Path(executable_dir).parents[sequence_no],target_path[i])
+                destination = pathlib.Path(os.path.join(Path(executable_dir).parents[sequence_no],target_path[i]))
         except Exception as e:
-            pkglogger.exceptionlogger("find_file","find_file",e,path_output=os.getcwd())
+            pkglogger.exceptionlogger("find_file","find_file",e,path_output=str(destination))
             print("Please pass correct format and check logs. Re-confirm the values you are passing...")
         
         
@@ -45,11 +51,14 @@ def find_file(sequence_no,target_path='',file_name='',extension=''):
         file_list = destination
     else:
         try:
-            file_list = list(destination.glob('*.' + extension))
+            if len(file_name) == 0:
+                file_list = list(destination.glob('*.' + extension))
+            else:
+                file_list = list(destination.glob(file_name + '.' + extension))
         except Exception as e:
-            pkglogger.exceptionlogger("find_file","find_file",e,path_output=executable_dir)
+            pkglogger.exceptionlogger("find_file","find_file",e,path_output=str(destination))
             print("Please pass correct extension and check logs. Re-confirm the values you are passing...")
-    print("Destinatio Directory :",destination)
+            print("Destination log Directory :",destination)
     return file_list
 
 
@@ -58,9 +67,10 @@ def find_file(sequence_no,target_path='',file_name='',extension=''):
 # Ex : 
 # str(pathfinder.find_file(0,['pkglogger'],'','py')[0])    
 # from pathfindwithinspace import pathfinder
+# print(str(pathfinder.find_file(0,'','','py')[0]))
+# print(str(find_file(0,'','__init__','py')[0]))
+# print(str(pathfinder.find_file(0,'','','py')[0]))
 
-# str(pathfinder.find_file(0,['pkglogger'],'','py')[0])
-        
         
         
         
